BFGraph: BlockedBloomFilter Class Reference

BFGraph

Public Member Functions
BlockedBloomFilter Class Reference

## Public Member Functions
| BlockedBloomFilter (size_t nb_elem, size_t bits_per_elem)
std::pair< uint64_t *, uint64_t * > | getBlock (uint64_t min_hash) const
bool | contains (uint64_t kmer_hash, const uint64_t min_hash) const
bool | contains (uint64_t kmer_hash, const std::pair< uint64_t *, uint64_t *> block_ptr) const
size_t | contains_block (uint64_t kmer_hash, const std::pair< const uint64_t *const, const uint64_t *const > block_ptr) const
bool | search_and_insert (uint64_t kmer_hash, const uint64_t min_hash, const bool multi_threaded=false)
void | insert (uint64_t kmer_hash, const uint64_t min_hash)
bool | WriteBloomFilter (FILE *fp)
bool | ReadBloomFilter (FILE *fp)
void | clear ()
void | get (BlockedBloomFilter &bf)
uint64_t | getNbBlocks () const
const uint64_t * | getTable_ptr () const

The documentation for this class was generated from the following file:

- src/BlockedBloomFilter.hpp